Typhon
======

A collection of tools for atmospheric research with Python 3.

Currently, it provides reading and writing routines for ARTS[1] XML files.


[1] Atmospheric Radiative Transfer Simulator: http://www.radiativetransfer.org/

